@@ -24,6 +24,7 @@
 #include <ccscript.h>
 #include <ctype.h>
 #include <new>
+#include <fstream>
 
 namespace ucommon {
 
@@ -433,7 +434,7 @@ Script *Script::compile(Script *merge, const char *fn, Script *cfg)
     stringbuf<512> buffer;
     char localname[128];
     Script *img;
-    file_t cf(fn, "r");
+    std::ifstream cf(fn);
     header *scr = NULL;
     const char *name = "_init_";
     Script::event *current;
@@ -460,7 +461,7 @@ Script *Script::compile(Script *merge, const char *fn, Script *cfg)
     char *ep;
     unsigned len;
 
-    if(!is(cf)) {
+    if(!cf.is_open()) {
         if(merge)
             return merge;
         return NULL;
@@ -525,7 +526,8 @@ initial:
     if(!img->first)
         img->first = scr;
 
-    while(when || label || define || cf.getline(buffer)) {
+    while(when || label || define || cf.getline(buffer.c_mem(), 512)) {
+        String::fix(buffer);
         if(define) {
             indented = true;
             goto parse;
